@@ -10,7 +10,7 @@ from copy import deepcopy
 from functools import reduce
 from importlib.util import spec_from_file_location, module_from_spec
 from itertools import groupby
-from typing import List, Dict, Union
+from typing import Callable, List, Dict, Union
 
 from lesscode_utils.encryption_algorithm import MD5
 
@@ -275,6 +275,26 @@ def sort_tree(data, sort_key="serial_index", children_key="children", reverse=Fa
     sort_dfs(data, sort_key=sort_key, children_key=children_key, reverse=reverse)
 
 
+def recursion_handle(data: Union[List[Dict], Dict], func: Callable, children_key="children"):
+    """
+    递归处理函数
+    :param data:
+    :param func:
+    :param children_key:
+    :return:
+    """
+
+    if isinstance(data, list):
+        data = func(data)
+        for i in data:
+            recursion_handle(i, func, children_key=children_key)
+    elif isinstance(data, dict):
+        if data.get(children_key):
+            data[children_key] = func(data)
+            for i in data.get(children_key):
+                recursion_handle(i, func, children_key=children_key)
+
+
 def tree2list(data_tree, key="children", parent_key="parent_key", data_key="key"):
     data_tree_tmp = copy.deepcopy(data_tree)
     data = []
